@@ -23,6 +23,18 @@ class ProfileSetRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cms', '2017-03-01', 'ProfileSet','cms')
 
+	def get_EnableInstallAgentNewECS(self):
+		return self.get_query_params().get('EnableInstallAgentNewECS')
+
+	def set_EnableInstallAgentNewECS(self,EnableInstallAgentNewECS):
+		self.add_query_param('EnableInstallAgentNewECS',EnableInstallAgentNewECS)
+
+	def get_EnableActiveAlert(self):
+		return self.get_query_params().get('EnableActiveAlert')
+
+	def set_EnableActiveAlert(self,EnableActiveAlert):
+		self.add_query_param('EnableActiveAlert',EnableActiveAlert)
+
 	def get_AutoInstall(self):
 		return self.get_query_params().get('AutoInstall')
 
